==> haskell-prettyprinter-1.7.1-330-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter
version:              1.7.1
visibility:           public
id:                   prettyprinter-1.7.1-1bGrHmHQilYFdKnOhsKcRi
key:                  prettyprinter-1.7.1-1bGrHmHQilYFdKnOhsKcRi
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:
    Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky, Simon Jakobi

homepage:             http://github.com/quchen/prettyprinter
synopsis:
    A modern, easy to use, well-documented, extensible pretty-printer.

description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md

category:             User Interfaces, Text
abi:                  da3c3aac8e7161831e6e4560c1057efc
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Debug
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util Prettyprinter Prettyprinter.Internal
    Prettyprinter.Internal.Debug Prettyprinter.Internal.Type
    Prettyprinter.Render.String Prettyprinter.Render.Text
    Prettyprinter.Render.Tutorials.StackMachineTutorial
    Prettyprinter.Render.Tutorials.TreeRenderingTutorial
    Prettyprinter.Render.Util.Panic
    Prettyprinter.Render.Util.SimpleDocTree
    Prettyprinter.Render.Util.StackMachine Prettyprinter.Symbols.Ascii
    Prettyprinter.Symbols.Unicode Prettyprinter.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/prettyprinter-1.7.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prettyprinter-1.7.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prettyprinter-1.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter
hs-libraries:         HSprettyprinter-1.7.1-1bGrHmHQilYFdKnOhsKcRi
depends:              base-4.17.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-1.7.1-332-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter
version:              1.7.1
visibility:           public
id:                   prettyprinter-1.7.1-AF4Gt6IhKUy3k7s13EBNuD
key:                  prettyprinter-1.7.1-AF4Gt6IhKUy3k7s13EBNuD
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:
    Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky, Simon Jakobi

homepage:             http://github.com/quchen/prettyprinter
synopsis:
    A modern, easy to use, well-documented, extensible pretty-printer.

description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md

category:             User Interfaces, Text
abi:                  0e24ab159b8384b8f02a8778f8c2481e
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Debug
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util Prettyprinter Prettyprinter.Internal
    Prettyprinter.Internal.Debug Prettyprinter.Internal.Type
    Prettyprinter.Render.String Prettyprinter.Render.Text
    Prettyprinter.Render.Tutorials.StackMachineTutorial
    Prettyprinter.Render.Tutorials.TreeRenderingTutorial
    Prettyprinter.Render.Util.Panic
    Prettyprinter.Render.Util.SimpleDocTree
    Prettyprinter.Render.Util.StackMachine Prettyprinter.Symbols.Ascii
    Prettyprinter.Symbols.Unicode Prettyprinter.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/prettyprinter-1.7.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prettyprinter-1.7.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prettyprinter-1.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter
hs-libraries:         HSprettyprinter-1.7.1-AF4Gt6IhKUy3k7s13EBNuD
depends:              base-4.17.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
